SystemOrganization addCategory: #'Zinc-Tests'!

TestCase subclass: #ZnBivalentWriteStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWriting
	| string |
	string := String streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray ].
	self assert: string asByteArray = #(97 98 99) asByteArray! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:43'!
testByteWritingToTranscript
	| writeStream |
	writeStream := ZnBivalentWriteStream on: Transcript.
	writeStream nextPut: 97; nextPutAll: #(98 99) asByteArray
! !

!ZnBivalentWriteStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 21:02'!
testCharacterWriting
	| bytes |
	bytes := ByteArray streamContents: [ :stream | | writeStream |
		writeStream := ZnBivalentWriteStream on: stream.
		writeStream nextPut: $a; space; nextPutAll: '123' ].
	self assert: bytes = 'a 123' asByteArray! !

TestCase subclass: #ZnChunkedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:07'!
testReading
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/2/2012 10:58'!
testReadingBuffered
	| data chunked plain buffer readStream |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	readStream := ZnChunkedReadStream on: chunked readStream.
	buffer := String new: 11.
	plain := String streamContents: [ :output | | readCount |
		[ readStream atEnd ] whileFalse: [
			readCount := readStream readInto: buffer startingAt: 1 count: buffer size.
			output next: readCount putAll: buffer ] ].
	self assert: plain equals: data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:18'!
testReadingGzip
	| data gzipped chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	plain := (GZipReadStream on: (ZnChunkedReadStream on: chunked readStream)) upToEnd.
	self assert: data = plain ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 15:17'!
testReadingGzipStepped
	| data gzipped chunked unchunked ungzipped |
	data := String withAll: ($a to: $z), ($A to: $Z).
	gzipped := String streamContents: [ :stream |
		(GZipWriteStream on: stream) nextPutAll: data; close ].
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: gzipped on: stream chunked: 16 ].
	unchunked := (ZnChunkedReadStream on: chunked readStream) upToEnd.
	ungzipped := (GZipReadStream on: unchunked) upToEnd.
	self assert: gzipped = unchunked.
	self assert: data = ungzipped ! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2011 17:39'!
testReadingNext
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := (ZnChunkedReadStream on: chunked readStream) next: 26 + 26.
	self assert: plain = data! !

!ZnChunkedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2011 17:40'!
testReadingNextInto
	| data chunked plain |
	data := String withAll: ($a to: $z), ($A to: $Z).
	chunked := String streamContents: [ :stream |
		ZnUtils nextPutAll: data on: stream chunked: 16 ].
	plain := String new: 26 + 26.
	(ZnChunkedReadStream on: chunked readStream) next: 26 + 26 into: plain.
	self assert: plain = data! !

TestCase subclass: #ZnClientTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:15'!
port
	^ 1700 + 10 atRandom! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testConstruction
	| client |
	(client := ZnClient new)
		http;
		host: 'www.example.com';
		port: 8080;
		addPath: 'foo';
		addPath: 'a space';
		addPath: 'file.txt';
		queryAt: 'key' put: '123456';
		headerAt: 'X-token' put: 'ABCDEF'.
	self assert: client request url host = 'www.example.com'.
	self assert: client request url port = 8080.
	self assert: client request url pathQueryFragmentPrintString = '/foo/a%20space/file.txt?key=123456'.
	self assert: (client request headers at: 'X-token') = 'ABCDEF'! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/14/2012 17:15'!
testCookies
	| client |
	self withServerDo: [ :server |
		server onRequestRespond: [ :request | | cookie1 cookie2 response |
			cookie1 := request cookies detect: [ :each | each name = 'x' ] ifNone: [ ZnCookie name: 'x' value: '0' ].
			cookie2 := request cookies detect: [ :each | each name = 'y' ] ifNone: [ ZnCookie name: 'y' value: '100' ].
			cookie1 value: (cookie1 value asInteger + 1) asString.
			cookie2 value: (cookie2 value asInteger + 2) asString.
			response := ZnResponse ok: (ZnEntity text: 'OK').
			response addCookie: cookie1; addCookie: cookie2.
			response ].
		client := ZnClient new url: server localUrl; yourself.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) isNil.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) isNil.
		client get.
		self assert: client isSuccess.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) value = '1'.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) value = '102'.
		client get.
		self assert: client isSuccess.
		self assert: (client session cookieJar cookieAt: 'x' forUrl: client request url) value = '2'.
		self assert: (client session cookieJar cookieAt: 'y' forUrl: client request url) value = '104'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testDownloadSmallHTML
	| client |
	ZnFileSystemUtils deleteIfExists: 'small.html'.
	"First download to a directory"
	(client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		downloadTo: ZnFileSystemUtils defaultDirectoryPath.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	ZnFileSystemUtils 
		oldFileNamed: 'small.html' 
		do: [ :stream | self assert: (stream upToEnd includesSubstring: 'Small') ].
	ZnFileSystemUtils deleteIfExists: 'small.html'.
	"Second download to an explicitly named file"
	client 
		url: 'http://zn.stfx.eu/zn/small.html';
		downloadTo: 'small.html'.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	ZnFileSystemUtils 
		oldFileNamed: 'small.html' 
		do: [ :stream | self assert: (stream upToEnd includesSubstring: 'Small') ].	
	client close.
	ZnFileSystemUtils deleteIfExists: 'small.html'.
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 21:19'!
testGetAfterPost
	self withServerDo: [ :server | | client |
		server onRequestRespond: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [
					(request method = #POST and: [ request hasEntity ])
						ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK for one') ]
						ifFalse: [ ZnResponse badRequest: request ] ]
				ifFalse: [
					request uri firstPathSegment = 'two'
						ifTrue: [ 
							(request method = #GET and: [ request hasEntity not ])
								ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK for two') ]
								ifFalse: [ ZnResponse badRequest: request ] ]
		 				ifFalse: [ ZnResponse notFound: request uri ] ] ].
		(client := ZnClient new) 
			url: server localUrl;
			url: 'one';
			entity: (ZnEntity text: 'One two three');
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK for one'.
		client
			url: 'two';
			get.
		self assert: client isSuccess.
		self assert: client contents = 'OK for two'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testGetGeoIP
	| result client |
	result := (client := ZnClient new)
		systemPolicy;
		url: 'http://easy.t3-platform.net/rest/geo-ip';
		queryAt: 'address' put: '81.83.7.35';
		accept: ZnMimeType applicationJson;
		contentReader: [ :entity | | parserClass |
			parserClass := Smalltalk at: #JSJsonParser ifAbsent: [ ^ self ].
			parserClass parse: entity contents ];
		ifFail: [ ^ self fail ];
		get.
	self assert: result isDictionary.
	self assert: (result at: #country) = 'BE'.
	client close.! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTML
	| client |
	(client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client isContentTypeAcceptable.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'Small').
	self assert: client isConnected.
	client close.
	self deny: client isConnected! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLOneShot
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'Small').
	self deny: client isConnected! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLStreaming
	| client result contents |
	result := (client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		streaming: true;
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: result isStream.
	self assert: client entity stream = result.
	contents := ZnUTF8Encoder new decodeBytes: result upToEnd.
	self assert: (contents includesSubstring: 'Small').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLTwice
	| client |
	(client := ZnClient new)
		url: 'http://zn.stfx.eu/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'Small').
	client 
		url: '/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'Small').
	client close.
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLUrlConstruction
	| client |
	(client := ZnClient new)
		http;
		host: 'zn.stfx.eu';
		path: '/zn/small.html';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'Small').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:13'!
testHeadSmallHTML
	| client |
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			head.
		self assert: client isSuccess.
		self assert: client response contentLength > 0.
		self assert: client response hasEntity not.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailNonExistingHost
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://unknown-stfx.eu';
		ifFail: [ : exception |
			^ self assert: (exception isKindOf: NetworkError) ];
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailNotFound
	| client |
	(client := ZnClient new)
		beOneShot;
		url: 'http://stfx.eu/non-existing';
		ifFail: [ :exception |
			^ self assert: (exception isKindOf: ZnHttpUnsuccessful) ];
		get.
	self assert: client isSuccess not.
	client
		enforceHttpSuccess: true;
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfFailWrongType
	| client |
	(client := ZnClient new)
		beOneShot;
		accept: ZnMimeType imagePng;
		enforceAcceptContentType: true;
		url: 'http://zn.stfx.eu/zn/small.html';
		ifFail: [ :exception |
			^ self assert: (exception isKindOf: ZnUnexpectedContentType) ];
		get.
	self fail! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testIfModifiedSinceNotModified
	| client request response |
	(client := ZnClient new) host: 'caretaker.wolf359.be'.
	[
		response := client 
			url: '/small.html'; 
			setIfModifiedSince: (Date year: 2011 month: 1 day: 1);
			get; 
			response.
		self assert: response isNotModified.
		self assert: response hasEntity not ] ensure: [ client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testLogging
	| client memoryLogger |
	memoryLogger := ZnMemoryLogger new.
	(client := ZnClient new)
		beOneShot.
	client log addListener: memoryLogger.
	client	get: 'http://zn.stfx.eu/zn/small.html'.
	client close.
	self deny: memoryLogger logEvents isEmpty! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPostForm
	| client |
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			formAt: 'username' put: 'john';
			formAdd: 'password' -> 'secret';
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'john').
		self assert: (client contents includesSubstring: 'secret') ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPostMultipart
	| client filename |
	ZnFileSystemUtils deleteIfExists: 'testPostMultiPart.txt'.
	filename := ZnFileSystemUtils fullNameFor: 'testPostMultiPart.txt'.
	ZnFileSystemUtils newFileNamed: filename do: [ :stream | stream nextPutAll: '0123456789' ].
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			addPart: (ZnMimePart fieldName: 'username' value: 'john');
			addPart: (ZnMimePart fieldName: 'foo' entity: (ZnEntity text: '123'));
			addPart: (ZnMimePart fieldName: 'file' fileNamed: filename);
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'multipart') ].
	ZnFileSystemUtils deleteIfExists: 'testPostMultiPart.txt'.
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 20:37'!
testPostTwice
	| client |
	self withServerDo: [ :server |
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			contents: 'Foo bar!!';
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Foo bar!!').
		client
			contents: 'Another one ?';
			post.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Another one ?').
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:19'!
testProgress
	"UIManager default informUserDuring: [ :bar |
		[ ^ ZnClient new
				signalProgress: true;
				get: 'http://zn.stfx.eu/echo?delay=2' ]
			on: HTTPProgress 
			do: [ :progress | bar value: progress printString. progress resume ] ]"
		
	self 
		should: [ 
			ZnClient new
				beOneShot;
				signalProgress: true;
				get: 'http://zn.stfx.eu/zn/small.html' ] 
		raise: HTTPProgress
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/20/2011 13:55'!
testProgressNoIfFail
	self 
		should: [ 
			ZnClient new
				beOneShot;
				signalProgress: true;
				ifFail: [ self fail ];
				get: 'http://zn.stfx.eu/zn/small.html' ] 
		raise: HTTPProgress
! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testQueryGoogle
	| client |
	(client := ZnClient new)
		http;
		host: 'www.google.com';
		addPath: 'search';
		queryAt: 'q' put: 'Pharo Smalltalk';
		get.
	self assert: client isSuccess.
	self assert: client response contentType = ZnMimeType textHtml.
	self assert: (client contents includesSubstring: 'pharo-project.org').
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/8/2011 22:16'!
testRedirect
	| client response |
	client := ZnClient new url: 'http://www.pharo-project.org'.
	self assert: (client get; isSuccess).
	client 
		close;
		maxNumberOfRedirects: 0;
		url: 'http://www.pharo-project.org'.
	self should: [ client get ] raise: ZnTooManyRedirects.
	client close.
	response := [ ZnClient new beOneShot; maxNumberOfRedirects: 0; get: 'http://www.pharo-project.org'; response ]
		on: ZnTooManyRedirects do: [ :exception | exception resume ].
	self assert: response isRedirect ! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/23/2011 17:13'!
testRedirectDontFollow
	| client |
	(client := ZnClient new) 
		dontFollowRedirects;
		get: 'http://www.pharo-project.org'.
	self assert: client response isRedirect.
	client
		enforceHttpSuccess: true;
		get: 'http://www.pharo-project.org'.
	self assert: client response isRedirect.
	client close! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/14/2012 17:16'!
testRedirectWithCookies
	self withServerDo: [ :server | | client cookie |
		server onRequestRespond: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [ 
					(ZnResponse redirect: 'two')
						addCookie: (ZnCookie name: 'session' value: '123456');
						yourself ]
				ifFalse: [
					cookie := request cookies detect: [ :each | each name = 'session' ] ifNone: [ nil ].
					(request uri firstPathSegment = 'two' and: [ cookie notNil and: [ cookie value = '123456' ] ])
						ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 				ifFalse: [ ZnResponse badRequest: request ] ] ].
		(client := ZnClient new) 
			url: server localUrl; addPath: 'one'; 
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK!!'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 20:33'!
testRedirectWithCustomHeader
	self withServerDo: [ :server | | client cookie |
		server onRequestRespond: [ :request | 
			(request headers at: 'X-Custom' ifAbsent: [ nil ]) = 'The Secret'
				ifFalse: [ ZnResponse badRequest: request ]
				ifTrue: [
					request uri firstPathSegment = 'one'
						ifTrue: [ ZnResponse redirect: 'two' ]
						ifFalse: [
							request uri firstPathSegment = 'two'
								ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 						ifFalse: [ ZnResponse badRequest: request ] ] ] ].
		(client := ZnClient new) 
			url: server localUrl; 
			addPath: 'one';
			headerAt: 'X-Custom' put: 'The Secret'; 
			get.
		self assert: client isSuccess.
		self assert: client contents = 'OK!!'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/14/2012 17:16'!
testRelativeRedirect
	self withServerDo: [ :server | | client |
		server onRequestRespond: [ :request | 
			request uri firstPathSegment = 'one'
				ifTrue: [ ZnResponse redirect: 'two' ]
				ifFalse: [
					request uri firstPathSegment = 'two'
						ifTrue: [ ZnResponse ok: (ZnEntity text: 'OK!!') ]
		 				ifFalse: [ ZnResponse notFound: request uri ] ] ].
		(client := ZnClient new) 
			url: server localUrl; addPath: 'one'; 
			post.
		self assert: client isSuccess.
		self assert: client contents = 'OK!!'.
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 20:14'!
testTimeout
	self withServerDo: [ :server |
		self 
			should: [ 
				ZnClient new 
					timeout: 1; 
					url: server localUrl;
					addPath: 'echo';
					queryAt: 'delay' put: '2'; 
					get ]
			raise: ConnectionTimedOut ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testUploadSmallDocument
	self withServerDo: [ :server | | client contents path |
		path := ZnFileSystemUtils fullNameFor: 'small.txt'.
		contents := String streamContents: [ :stream |
			stream print: DateAndTime now; space; print: 9999 atRandom ].
		ZnFileSystemUtils deleteIfExists: 'small.txt'.
		ZnFileSystemUtils newFileNamed: path do: [ :stream | stream nextPutAll: contents ].
		(client := ZnClient new)
			url: server localUrl;
			addPath: 'echo';
			uploadEntityFrom: path.
		self assert: client request entity contentType = ZnMimeType textPlain.
		client contentType: ZnMimeType textPlain. "Not needed, just test the code path"
		self assert: client request entity contentType = ZnMimeType textPlain.
		client post.
		self assert: client isSuccess.
		self assert: client entity contentType = ZnMimeType textPlain.
		self assert: (client contents includesSubstring: contents).
		client close.
		ZnFileSystemUtils deleteIfExists: 'small.txt' ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 20:19'!
testUsernamePassword
	self withServerDo: [ :server | | client |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		(client := ZnClient new) 
			url: server localUrl;
			addPathSegment: 'echo';
			get.
		self deny: client isSuccess.
		self assert: client response isAuthenticationRequired.
		client 
			username: 'foo' password: 'secret'; 
			get.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Zinc').
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/30/2013 19:19'!
testUsernamePasswordInUserInfo
	self withServerDo: [ :server | | url client |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		url := server localUrl.
		url username: 'foo'; password: 'secret'; addPathSegment: 'echo'.
		(client := ZnClient new) 
			get: url.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Zinc').
		client close ]! !

!ZnClientTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 20:20'!
testUsernamePasswordTwice
	self withServerDo: [ :server | | client |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		(client := ZnClient new) 
			url: server localUrl;
			addPathSegment: 'echo';
			username: 'foo' password: 'secret'; 
			get.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Zinc').
		client get.
		self assert: client isSuccess.
		self assert: (client contents includesSubstring: 'Zinc').
		client close ]! !

!ZnClientTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 8/31/2011 21:59'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnDigestAuthenticatorTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnDigestAuthenticatorTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/22/2012 10:12'!
testParseEmpty
	| keys headerValue |
	headerValue := ' Digest username="Mufasa",
                     realm="testrealm@host.com",
                     nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093",
                     uri="/dir/index.html",
                     qop=,
                     nc="",
                     cnonce="0a4f113b",
                     response="6629fae49393a05397450978507c4ef1",
                     opaque="5ccc069c403ebaf9f0171e9517f40e41"'.
	keys := ZnDigestAuthenticator parseAuthRequest: headerValue.
	self assert: (keys at: 'username') equals: 'Mufasa'.
	self assert: (keys at: 'realm') equals: 'testrealm@host.com'.
	self assert: (keys at: 'qop') equals: ''.
	self assert: (keys at: 'nc') equals: ''.
	self assert: (keys at: 'cnonce') equals: '0a4f113b'.
	self assert: (keys at: 'response') equals: '6629fae49393a05397450978507c4ef1'.
	! !

!ZnDigestAuthenticatorTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/22/2012 10:11'!
testParseOK
	| keys headerValue |
	headerValue := ' Digest username="Mufasa",
                     realm="testrealm@host.com",
                     nonce="dcd98b7102dd2f0e8b11d0f600bfb0c093",
                     uri="/dir/index.html",
                     qop=auth,
                     nc=00000001,
                     cnonce="0a4f113b",
                     response="6629fae49393a05397450978507c4ef1",
                     opaque="5ccc069c403ebaf9f0171e9517f40e41"'.
	keys := ZnDigestAuthenticator parseAuthRequest: headerValue.
	self assert: (keys at: 'username') equals: 'Mufasa'.
	self assert: (keys at: 'realm') equals: 'testrealm@host.com'.
	self assert: (keys at: 'qop') equals: 'auth'.
	self assert: (keys at: 'nc') equals: '00000001'.
	self assert: (keys at: 'cnonce') equals: '0a4f113b'.
	self assert: (keys at: 'response') equals: '6629fae49393a05397450978507c4ef1'.
	! !

TestCase subclass: #ZnDispatcherDelegateTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnDispatcherDelegateTest methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:10'!
port
	^ 1700 + 10 atRandom! !

!ZnDispatcherDelegateTest methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:13'!
testDispatcherDelegate
	self withServerDo: [ :server |  | client |
		server delegate: (ZnDispatcherDelegate new 
			map: '/hello' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>hello server</h1>') ];
			map: '/' to: [ :request :response | response entity: (ZnStringEntity html: '<h1>default</h1>') ]).

		client := ZnClient new.
		
		client get: (server localUrl addPathSegment: 'missing'; yourself).
		self assert: (client response contentType = ZnMimeType textPlain).
		self assert: (client response status = 404).
		
		client get: server localUrl.
		self assert: (client response contentType = ZnMimeType textHtml).
		self assert: (client response status = 200).
		
		client get: (server localUrl addPathSegment: 'hello'; yourself).
		self assert: (client response contentType = ZnMimeType textHtml).
		self assert: (client response status = 200).
		
		client close ]! !

!ZnDispatcherDelegateTest methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:10'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnEasyTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEasyTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:02'!
port
	^ 1700 + 10 atRandom! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testDelete
	self withServerDo: [ :server | | response |
		response := ZnEasy delete: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubstring: 'DELETE').
		self assert: (response entity string includesSubstring: 'foo') ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2011 16:34'!
testGetJpeg
	| url result |
	url := 'http://caretaker.wolf359.be/sun-fire-x2100.jpg'.
	result := ZnEasy getJpeg: url.
	self assert: result isForm! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLDocument
	| url response |
	url := 'http://zn.stfx.eu/zn/small.html'.
	response := ZnEasy get: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: (response entity string includesSubstring: 'small')! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 7/4/2012 17:33'!
testHeadSmallHTMLDocument
	| url response |
	url := 'http://zn.stfx.eu/zn/small.html'.
	response := ZnEasy head: url.
	self assert: (response headers contentType = ZnMimeType textHtml).
	self assert: (response statusLine code = 200).
	self assert: response hasEntity not! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPost
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
		response := ZnEasy post: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubstring: 'POST').
		self assert: (response entity string includesSubstring: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPostUnicodeUtf8
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 0 to: 16r024F do: [ :each | stream nextPut: each asCharacter ] ].
		response := ZnEasy post: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubstring: 'POST').
		self assert: (response entity string includesSubstring: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPut
	self withServerDo: [ :server | | response data |
		data := String streamContents: [ :stream | 1 to: 32 do: [ :each | stream nextPut: 'abc' atRandom ] ].
		response := ZnEasy put: (server localUrl addPathSegment: 'echo'; yourself) data: (ZnEntity text: data).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubstring: 'PUT').
		self assert: (response entity string includesSubstring: data) ]! !

!ZnEasyTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 21:07'!
testTimeout
	self withServerDo: [ : server |
		self 
			should: [ 
				ZnConnectionTimeout 
					value: 1 
					during: [ ZnEasy get: (server localUrl addPathSegment: 'echo'; queryAt: 'delay' put: '2'; yourself) ] ] 
			raise: ConnectionTimedOut ]
	! !

!ZnEasyTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 21:02'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnEntityReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:03'!
testChunked
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 16:04'!
testChunkedWithExtraHeaders
	| input headers reader entity |
	input := '3', String crlf,
		'con', String crlf,
		'8', String crlf,
		'sequence', String crlf,
		'0', String crlf, 
		'X-Foo:bar', String crlf, 
		String crlf.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: 'text/plain';
		at: 'Transfer-Encoding' put: 'chunked'.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: input asByteArray readStream.
	entity := reader readEntity.
	self assert: entity contents = 'consequence'.
	self assert: (headers at: 'X-Foo') = 'bar'! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:08'!
testReadStreaming
	| data headers reader entity |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	self assert: entity contents = data! !

!ZnEntityReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:13'!
testReadStreamingWriting
	| data headers reader entity output |
	data := ((1 to: 32) collect: [ :each | (0 to: 9) atRandom ]) asByteArray.
	(headers := ZnHeaders new)
		at: 'Content-Type' put: ZnMimeType applicationOctetStream printString;
		at: 'Content-Length' put: data size printString.
	(reader := ZnEntityReader new)
		headers: headers;
		stream: data readStream;
		streaming.
	entity := reader readEntity.
	self assert: entity contentType = ZnMimeType applicationOctetStream.
	self assert: entity contentLength = data size.
	output := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: output = data! !

TestCase subclass: #ZnEntityTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/27/2011 17:15'!
testMultiPartFormDataWriteRead
	| input output bytes |
	input := (ZnMultiPartFormDataEntity new)
		addPart: (ZnMimePart fieldName: 'extra' value: 'my-extra');
		addPart: (ZnMimePart fieldName: 'info' value: 'my-info');
		addPart: (ZnMimePart fieldName: 'file' fileName: 'foo.txt' entity: (ZnEntity text: 'Zinc HTTP Components'));
		yourself.
	self assert: input contentLength notNil.
	self assert: input contentLength > 0.
	self assert: input contentType = ZnMimeType multiPartFormData.
	bytes := ByteArray streamContents: [ :stream | input writeOn: stream ].
	output := (ZnMultiPartFormDataEntity type: input contentType) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.
	output := (ZnMultiPartFormDataEntity type: input contentType length: input contentLength) readFrom: bytes readStream.
	self assert: (output partNamed: 'extra') fieldValueString = 'my-extra'.
	self assert: (output partNamed: 'info') fieldValueString = 'my-info'.
	self assert: (output partNamed: 'file') contents = 'Zinc HTTP Components'.

	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/3/2010 15:41'!
testReading
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self assert: entity contents isString.
	self assert: entity string = contents.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/25/2013 14:41'!
testReadingApplicationFormUrlEncoding
	| input entity |
	input := #(111 97 117 116 104 95 116 111 107 101 110 95 115 101 99 114 101 116 61 98 121 112 104 57 99 109 104 106 49 53 101 108 121 56 38 111 97 117 116 104 95 116 111 107 101 110 61 56 54 101 112 106 51 116 118 100 49 107 115 120 111 57)
		asByteArray.
	entity := ZnEntity readFrom: input readStream usingType: ZnMimeType applicationFormUrlEncoded andLength: input size.
	self deny: entity isEmpty.
	self assert: (entity includesField: 'oauth_token_secret').
	self assert: (entity includesField: 'oauth_token').
	self assert: (entity at: 'oauth_token_secret') equals: 'byph9cmhj15ely8'.
	self assert: (entity at: 'oauth_token') equals: '86epj3tvd1ksxo9'! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/25/2013 14:41'!
testReadingApplicationFormUrlEncodingNoLength
	| input entity |
	input := #(111 97 117 116 104 95 116 111 107 101 110 95 115 101 99 114 101 116 61 98 121 112 104 57 99 109 104 106 49 53 101 108 121 56 38 111 97 117 116 104 95 116 111 107 101 110 61 56 54 101 112 106 51 116 118 100 49 107 115 120 111 57)
		asByteArray.
	entity := ZnEntity readFrom: input readStream usingType: ZnMimeType applicationFormUrlEncoded andLength: nil.
	self deny: entity isEmpty.
	self assert: (entity includesField: 'oauth_token_secret').
	self assert: (entity includesField: 'oauth_token').
	self assert: (entity at: 'oauth_token_secret') equals: 'byph9cmhj15ely8'.
	self assert: (entity at: 'oauth_token') equals: '86epj3tvd1ksxo9'! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/7/2012 17:45'!
testReadingBinary
	| contents entity |
	contents := 'This is a test'.
	entity := ZnEntity 
				readBinaryFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size.
	self deny: entity contents isString.
	self assert: entity contents = contents asByteArray.
	self assert: entity contentLength = contents size.
	self assert: entity contentType = ZnMimeType textPlain ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/5/2012 12:39'!
testReadingLimited
	| contents |
	contents := String new: 1025 withAll: $X.
	ZnMaximumEntitySize value: 1024 during: [
		self should: [
			ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: contents size ]
			raise: ZnEntityTooLarge.
		self should: [
			ZnEntity 
				readFrom: contents asByteArray readStream 
				usingType: ZnMimeType textPlain 
				andLength: nil ]
			raise: ZnEntityTooLarge ] ! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/14/2010 12:13'!
testStringEntityEncoderInitialization
	| entity response |
	entity := ZnEntity text: 'Regression test'.
	self assert: entity hasEncoder not.
	response := ZnResponse ok: entity.
	self assert: entity hasEncoder.
	ByteArray streamContents: [ :stream | response writeOn: stream ].
	self assert: entity hasEncoder
	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingDetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain length: 10.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8ReadingUndetermined
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity type: ZnMimeType textPlain.
	bytes := #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray.
	entity readFrom: bytes readStream.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	self assert: entity contents = string! !

!ZnEntityTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:46'!
testUTF8Writing
	| string entity bytes |
	string := String with: $$ with: (16r00A2 asCharacter) with: ( 16r20AC asCharacter) with: (16r024B62 asCharacter).
	entity := ZnStringEntity text: string.
	self assert: entity contentType = ZnMimeType textPlain.
	self assert: entity contentLength = 10.
	bytes := ByteArray streamContents: [ :stream | entity writeOn: stream ].
	self assert: bytes = #(16r24 16rC2 16rA2 16rE2 16r82 16rAC 16rF0 16rA4 16rAD 16rA2) asByteArray! !

!ZnEntityTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 10:11'!
testWritingApplicationUrlEncoding
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity at: 'foo' put: 'bar'.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=bar'.
	self assert: entity contentLength = 7! !

!ZnEntityTests methodsFor: 'testing' stamp: 'NorbertHartl 12/6/2011 18:33'!
testWritingApplicationUrlEncodingWithTextEncodingLatin1
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity contentType charSet: 'iso-8859-1'.
	entity at: 'foo' put: (Character value: 246) asString.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=%F6'.
	self assert: entity contentLength = 7
	! !

!ZnEntityTests methodsFor: 'testing' stamp: 'NorbertHartl 12/6/2011 18:33'!
testWritingApplicationUrlEncodingWithTextEncodingUtf8
	| entity string |
	entity := ZnApplicationFormUrlEncodedEntity new.
	entity contentType charSet: 'utf-8'.
	entity at: 'foo' put: (Character value: 246) asString.
	string := String streamContents: [ :stream | entity writeOn: stream ].
	self assert: string = 'foo=%C3%B6'.
	self assert: entity contentLength = 10! !

TestCase subclass: #ZnHTTPSocketFacadeTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/30/2011 13:59'!
testExtendUrlWithArgs
	| url |
	url := ZnHTTPSocketFacade 
		extendUrl: 'http://www.foo.com/bar' 
		withArguments: (Dictionary new
			at: 'x' put: #('1');
			at: 'z' put: #('aaa' 'bbb');
			yourself).
	self assert: url host = 'www.foo.com'.
	self assert: url path = 'bar'.
	self assert: (url queryAt: 'x') = '1'.
	self assert: (url queryAt: 'z') = #('aaa' 'bbb')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLDocument
	| mimeDocument |
	mimeDocument := ZnHTTPSocketFacade httpGetDocument: 'http://zn.stfx.eu/zn/small.html'.
	self assert: (mimeDocument contents includesSubstring: 'small').
	self assert: (mimeDocument contentType includesSubstring: 'text/html')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetSmallHTMLStream
	| stream |
	stream := ZnHTTPSocketFacade httpGet: 'http://zn.stfx.eu/zn/small.html'.
	self assert: (stream contents includesSubstring: 'small')! !

!ZnHTTPSocketFacadeTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testPut
	| server result dataString |
	server := ZnServer on: (1700 + 10 atRandom).
	server authenticator: (ZnBasicAuthenticator username: 'user' password: 'secret').
	dataString := String streamContents: [ :stream | 
		1 to: 67 do: [ :each | stream nextPut: (Character digitValue: each \\ 9) ] ].
	[ 
		server start.
		result := ZnHTTPSocketFacade 
			httpPut: dataString 
			to: (server localUrl addPathSegments: #('echo' 'foo'); yourself)
			user: 'user' 
			passwd: 'secret'.
		self assert: (result beginsWith: 'HTTP/1.1 200 OK').
		self assert: (result includesSubstring: '67B')
	]
		ensure: [ server stop ]! !

TestCase subclass: #ZnHeadersTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:59'!
testMergeValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' put: 'bar=1' ifPresentMerge: [ :old :new | old, ';', new ].
	self assert: (headers at: 'Set-Cookie') = 'foo=1;bar=1'
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:57'!
testMultiValued
	| headers |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	self assert: (headers at: 'Set-Cookie') = #('foo=1' 'bar=1')
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 21:03'!
testMultiValuedStreaming
	| headers keysAndValues |
	headers := ZnHeaders new.
	headers at: 'Set-Cookie' put: 'foo=1'.
	headers at: 'Set-Cookie' add: 'bar=1'.
	keysAndValues := OrderedCollection streamContents: [ : stream |
		headers headersDo: [ :key :value |
			stream nextPut: key; nextPut: value ] ].
	self assert: keysAndValues  = #('Set-Cookie' 'foo=1' 'Set-Cookie' 'bar=1') asOrderedCollection 
	
	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:55'!
testNormalization
	| headers |
	headers := ZnHeaders new.
	headers at: 'content-TYPE' put: 'text/plain'.
	self assert: (headers includesKey: 'content-type').
	self assert: (headers includesKey: 'content-TYPE').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	headers at: 'CONTENT-type' put: 'text/html'.
	self assert: (headers at: 'Content-Type') = 'text/html'.

	! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/6/2010 20:16'!
testReading
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/22/2012 10:42'!
testReadingMultiline
	| string headers |
	string := 'Content-Type: text/plain', String crlf, 
		'Long: foo', String crlf, 
		' bar', String crlf, 
		String tab, 'baz', String crlf, 
		'Content-Length: 128', String crlf.
	headers := ZnHeaders readFrom: string readStream.
	self assert: (headers includesKey: 'Content-Type').
	self assert: (headers includesKey: 'Content-Length').
	self assert: (headers at: 'Content-Type') = 'text/plain'.
	self assert: (headers at: 'Content-Length') = '128'.
	self assert: (headers includesKey: #Long).
	self assert: (headers at: #long) equals: 'foo bar	baz'.! !

!ZnHeadersTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testWriting
	| headers string |
	headers := ZnHeaders new 
		at: 'Content-Type' put: 'text/plain'; 
		at: 'Content-Length' put: '128';
		yourself.
	string := String streamContents: [ :stream | headers writeOn: stream ].
	self assert: (string includesSubstring: 'Content-Type: text/plain', String crlf).
	self assert: (string includesSubstring: 'Content-Length: 128', String crlf).
	self assert: (string occurrencesOf: Character cr) = 2.
	self assert: (string occurrencesOf: Character lf) = 2! !

TestCase subclass: #ZnLimitedReadStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinary
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = #(0 1 2 3 4) asByteArray! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:47'!
testBinaryAll
	| data limitedReadStream |
	data := #(0 1 2 3 4 5 6 7 8 9) asByteArray.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: data size.
	self assert: limitedReadStream upToEnd = data! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/2/2012 16:05'!
testMatch
	| stream |
	stream := ZnLimitedReadStream on: 'ababcabc' readStream limit: 8.
	self assert: (stream match: 'ab').
	self deny: stream atEnd.
	stream := ZnLimitedReadStream on: 'ababcabc' readStream limit: 8.
	self assert: (stream match: 'abc').
	self deny: stream atEnd.
	self assert: (stream match: 'abc').
	self assert: stream atEnd.
	stream := ZnLimitedReadStream on: 'ababcabc' readStream limit: 8.
	self deny: (stream match: 'xx').
	self assert: stream atEnd.
! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:49'!
testNext
	| limitedReadStream |
	limitedReadStream := ZnLimitedReadStream on: String new readStream limit: 10.
	self assert: limitedReadStream atEnd.
	self assert: limitedReadStream next isNil.
	limitedReadStream := ZnLimitedReadStream on: 'ABC' readStream limit: 10.
	self assert: limitedReadStream atEnd not.
	self assert: limitedReadStream next = $A.
	self assert: limitedReadStream peek = $B.
	limitedReadStream next.
	self assert: limitedReadStream next = $C.
	self assert: limitedReadStream next isNil.
	self assert: limitedReadStream atEnd
	! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCount
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	self assert: (stream next: 4) = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:26'!
testNextCountInto
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 8.
	buffer := String new: 4.
	self assert: (stream next: 4 into: buffer) = '0123'.
	self assert: buffer = '0123'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:41'!
testNextCountIntoShort
	| data stream buffer |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	buffer := String new: 6.
	self assert: (stream next: 6 into: buffer) = '01234'
	! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/21/2011 23:24'!
testNextCountShort
	| data stream |
	data := '0123456789'.
	stream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: (stream next: 6) = '01234'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 13:04'!
testSimple
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 5.
	self assert: limitedReadStream upToEnd = '01234'! !

!ZnLimitedReadStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 20:45'!
testSimpleEof
	| data limitedReadStream |
	data := '0123456789'.
	limitedReadStream := ZnLimitedReadStream on: data readStream limit: 15.
	self assert: limitedReadStream upToEnd = '0123456789'.
	self assert: limitedReadStream atEnd.
	self assert: limitedReadStream next isNil! !

TestCase subclass: #ZnLineReaderTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:22'!
testBinary
	| input reader |
	input := ('Foo', String crlf, 'Bar', String crlf) asByteArray.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 2/28/2011 14:21'!
testLineTooLong
	| input reader |
	input := (String new: 128) atAllPut: $X.
	reader := (ZnLineReader on: input readStream) limit: 64.
	self should: [ reader nextLine ] raise: ZnLineTooLong  ! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/2/2012 19:18'!
testLineTooLongDefault
	| input reader |
	input := (String new: ZnConstants maximumLineLength + 1) atAllPut: $X.
	reader := ZnLineReader on: input readStream.
	self should: [ reader nextLine ] raise: ZnLineTooLong  ! !

!ZnLineReaderTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/27/2010 19:02'!
testSimple
	| input reader |
	input := 'Foo', String crlf, 'Bar', String crlf.
	reader := ZnLineReader on: input readStream.
	self assert: reader nextLine = 'Foo'.
	self assert: reader nextLine = 'Bar'.
	self assert: reader nextLine isEmpty! !

TestCase subclass: #ZnLogSupportTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 14:59'!
testFilter
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	memoryLogger filter: #info.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport debug: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 4/13/2011 00:23'!
testLogEvent
	| logEvent now |
	now := TimeStamp now.
	logEvent := ZnLogEvent info: 'Testing'.
	self assert: logEvent timeStamp >= now.
	self assert: logEvent processId isInteger.
	self assert: logEvent category = #info.
	self assert: logEvent message = 'Testing'  ! !

!ZnLogSupportTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/29/2011 11:42'!
testSimple 
	| logSupport memoryLogger |
	logSupport := ZnLogSupport newEnabled.
	memoryLogger := ZnMemoryLogger new.
	logSupport addListener: memoryLogger.
	logSupport info: 'Testing'.
	self assert: memoryLogger logEvents first message = 'Testing'.
	logSupport removeListener: memoryLogger.
	logSupport info: 'Void'.
	self assert: memoryLogger logEvents size = 1     
	! !

TestCase subclass: #ZnMagicCookieJarTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 9/28/2012 12:39'!
cookieString
	^ 'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires={1}; path=/; domain=.google.com' format: { ZnUtils httpDate: DateAndTime now + 60 days }! !

!ZnMagicCookieJarTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 9/28/2012 12:39'!
cookieStringAlt
	^'PREFS=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires={1}; path=/; domain=.pharo-project.org' format: { ZnUtils httpDate: DateAndTime now + 60 days }! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:19'!
testAdd
	| jar count |
	jar := ZnCookieJar new.
	count := jar cookies size.
	jar add: (ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl).
	self assert: ((jar cookies size) = (count + 1))! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:03'!
testCookieAtForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookieAt: 'PREF' forUrl: 'http://www.google.com' asZnUrl) notNil).
	self assert: ((jar cookieAt: 'foobar' forUrl: 'http://www.google.com' asZnUrl) isNil)! !

!ZnMagicCookieJarTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:02'!
testCookiesForUrl
	| jar c1 c2 |
	jar := ZnCookieJar new.
	c1 := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	c2 := ZnCookie fromString: self cookieStringAlt for: 'http://www.pharo-project.org' asZnUrl.
	jar add: c1; add: c2.
	self assert: ((jar cookiesForUrl: 'http://www.google.com' asZnUrl) size = 1)! !

TestCase subclass: #ZnMagicCookieTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/28/2012 12:38'!
cookieString
	^ 'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires={1}; path=/; domain=.google.com' format: { ZnUtils httpDate: DateAndTime now + 60 days }! !

!ZnMagicCookieTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 9/28/2012 12:38'!
cookieStringSubpath
	^ 'PREF=ID=18ae67ce302b6317:TM=1285696140:LM=1285696140:S=hqroFGlRQR1j4Yhy; expires={1}; path=/test/; domain=.google.com' format: { ZnUtils httpDate: DateAndTime now + 60 days }! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testFromString
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'www.google.com' asZnUrl.
	self assert: (cookie name = 'PREF').
	self assert: (cookie path notNil).
	self assert: (cookie domain = '.google.com').
	self assert: (cookie isExpired not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 15:01'!
testInDomain
	| cookie |
	cookie := ZnCookie fromString: self cookieString for: 'http://www.google.com' asZnUrl.
	self assert: (cookie isInDomain: 'http://www.google.com' asZnUrl).
	self assert: (cookie isInDomain: 'http://google.com' asZnUrl).
	self assert: ((cookie isInDomain: 'http://pharo-project.org' asZnUrl) not)
	! !

!ZnMagicCookieTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2011 14:20'!
testInPath
	| cookie |
	cookie := ZnCookie fromString: self cookieStringSubpath for: 'www.google.com' asZnUrl.
	self assert: (cookie isInPath: 'www.google.com/test/' asZnUrl).
	self assert: ((cookie isInPath: 'www.google.com' asZnUrl) not)
	! !

TestCase subclass: #ZnRequestLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:08'!
testReading
	| requestLine string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.1', String crlf.
	requestLine := ZnRequestLine readFrom: string readStream.
	self assert: requestLine method = #GET.
	self assert: requestLine uriPathQueryFragment = '/foo/bar/xyz.txt'.
	self assert: requestLine version = ZnConstants defaultHTTPVersion ! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:04'!
testReadingWrongMethod
	| string |
	string := 'GETT /foo/bar/xyz.txt HTTP/1.1', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknownHttpMethod! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion
	| string |
	string := 'GET /foo/bar/xyz.txt HTTP/1.5', String crlf.
	self should: [ ZnRequestLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnRequestLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:11'!
testWriting
	| requestLine string |
	requestLine := ZnRequestLine method: 'GET' uri: '/foo/bar/xyz.txt'.
	string := String streamContents: [ :stream | requestLine writeOn: stream ].
	self assert: string = ('GET /foo/bar/xyz.txt HTTP/1.1', String crlf)! !

TestCase subclass: #ZnRequestTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/12/2010 20:25'!
testBasicAuthenticate
	| request |
	request := ZnRequest new.
	request setBasicAuthenticationUsername: 'user' password: 'secret'.
	self assert: (request headers at: 'Authorization') = 'Basic dXNlcjpzZWNyZXQ='! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/4/2012 21:40'!
testCookiesParsing
	| input request cookies testCookie1 testCookie2 |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Cookie: testCookie1=123; testCookie2=321', String crlf,
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	
	cookies := request cookies.
	testCookie1 := cookies detect: [ :each | each name = 'testCookie1' ].
	testCookie2 := cookies detect: [ :each | each name = 'testCookie2' ].
	
	self assert: testCookie1 notNil.
	self assert: testCookie1 value = '123'.	
	
	self assert: testCookie2 notNil.
	self assert: testCookie2 value = '321'.	

! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/4/2012 23:18'!
testCookiesWriting
	|  client testCookie1 testCookie2 cookieString cookies|
	client := ZnClient new.
	client url: 'http://www.example.com'.
	(testCookie1 := ZnCookie name: 'testCookie1' value: '123')
		domain: 'example.com'.
	(testCookie2 := ZnCookie name: 'testCookie2' value: '321')
		domain: 'example.com'.
	(client session cookieJar)
		add: testCookie1;
		add: testCookie2.
	client sendCookies.
	cookies := client request cookies do: [ :each | each defaultDomain: 'example.com' ].
	self assert: (cookies includes: testCookie1).
	self assert: (cookies includes: testCookie2)
	
		
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/7/2013 11:05'!
testMergedFields
	| request form mergedFields |
	request := ZnRequest post: 'http://host.com/foo?x=1&y=2&x=3'.
	form := ZnApplicationFormUrlEncodedEntity new.
	form
		at: #z put: '100';
		at: #z add: '200';
		at: #y put: '0'.
	request entity: form.
	mergedFields := request mergedFields.
	self assert: mergedFields keys sorted equals: #(x y z).
	self assert: (mergedFields at: #x) sorted equals: #('1' '3').
	self assert: (mergedFields at: #y) sorted equals: #('0' '2').
	self assert: (mergedFields at: #z) sorted equals: #('100' '200')! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:34'!
testReading
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Agent: SUnit', String crlf, 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: (request headers at: 'Host') = 'foo.com'.
	self assert: request hasEntity not
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/4/2010 13:35'!
testReadingWithEntity
	| input request |
	input := 'GET /foo.html HTTP/1.1', String crlf, 
		'Host: foo.com', String crlf, 
		'Content-Length: 8', String crlf, 
		'Content-Type: text/plain', String crlf, 
		String crlf, 
		'12345678'.
	request := ZnRequest readFrom: input asByteArray readStream.
	self assert: request method = #GET.
	self assert: request hasHeaders.
	self assert: request contentType = ZnMimeType textPlain.
	self assert: request contentLength = 8.
	self assert: request hasHeaders.
	self assert: request entity contents = '12345678'
! !

!ZnRequestTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/7/2013 09:09'!
testUrl
	| url request input |
	url := 'http://zn.stfx.eu/zn/small.thml' asZnUrl.
	request := ZnRequest get: url.
	"The original URL is kept inside the request line object inside the request object"
	self assert: request url equals: url.
	self assert: request relativeUrl equals: url asRelativeUrl.
	self assert: request absoluteUrl equals: url.
	url := 'http://foo.com/foo.html' asZnUrl.
	input := 'GET /foo.html HTTP/1.1' , String crlf , 
		'Host: foo.com' , String crlf , 
		String crlf.
	request := ZnRequest readFrom: input readStream.
	self assert: request url equals: url asRelativeUrl.
	self assert: request relativeUrl equals: url asRelativeUrl.
	self assert: request absoluteUrl equals: url! !

TestCase subclass: #ZnResponseTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 22:42'!
testAbsoluteCreated
	| response uri |
	uri := 'http://www.example.com:8888/something/else/foo.txt'.
	response := ZnResponse created: uri asZnUrl.
	self assert: response code = 201.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubstring: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 22:37'!
testAbsoluteRedirect
	| response uri |
	uri := 'http://foo.com:8080/something/else/foo.txt?key=123'.
	response := ZnResponse redirect: uri asZnUrl.
	self assert: response code = 302.
	self assert: response isRedirect.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubstring: uri)
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testCookie
	| response cookie1  responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	response addCookie: cookie1.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubstring: 'Set-Cookie: testCookie1=123')	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testCookies
	| response cookie1 cookie2 responseString |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	cookie1 := ZnCookie new.
	cookie1 
		name: 'testCookie1';
		value: '123'.
		
	cookie2 := ZnCookie new.
	cookie2 
		name: 'testCookie2';
		value: '321'.
		
	response addCookie: cookie1.
	response addCookie: cookie2.
	
	responseString := String streamContents: [ :stream | response writeOn: stream ].
	
	self assert: (responseString includesSubstring: 'Set-Cookie: testCookie1=123').  
	self assert: (responseString includesSubstring: 'Set-Cookie: testCookie2=321').  	

	
		
		
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testCreated
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse created: uri.
	self assert: response code = 201.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubstring: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'PaulDeBruicker 4/19/2012 17:01'!
testIsError
	| response |
	response := ZnResponse ok: (ZnStringEntity html: '<h1>hello world</h1>').
	self assert: response isError not.
	response := ZnResponse notFound: 'http:///secret.txt'.
	self assert: response isError.
	response := ZnResponse redirect: '/something/else/foo.txt'.
	self assert: response isError not! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testNotFound
	| response |
	response := ZnResponse notFound: 'http:///secret.txt'.
	self assert: response code = 404.
	self assert: (response headers includesKey: 'Server').
	self assert: (response headers includesKey: 'Date').
	self assert: (response entity contents includesSubstring: 'secret.txt')! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/6/2013 22:38'!
testRedirect
	| response uri |
	uri := '/something/else/foo.txt'.
	response := ZnResponse redirect: uri.
	self assert: response code = 302.
	self assert: response code = 302.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubstring: uri).
	response := ZnResponse redirect: uri asZnUrl.
	self assert: response code = 302.
	self assert: response code = 302.
	self assert: response hasHeaders.
	self assert: (response headers at: 'Location') = uri.
	self assert: response hasEntity.
	self assert: (response entity contents includesSubstring: uri)! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testSlashdotGzipChunked
	| request stream response contents |
	(request := ZnRequest get: 'http://slashdot.org')
		setConnectionClose;
		setAcceptEncodingGzip.
	stream := ZnNetworkingUtils socketStreamToUrl: request url.
	response := [ 
  		request writeOn: stream. 
  		stream flush. 
  		ZnResponse readFrom: stream ] ensure: [ stream close ].
	response isRedirect ifTrue: [ ^ self ].
	self assert: response code = 200.
	self assert: ((response headers at: 'Content-Type') beginsWith: 'text/html').
	self assert: (response headers at: 'Content-Encoding' ifAbsent: [ 'gzip' ]) = 'gzip'.
	self assert: (response headers at: 'Transfer-Encoding' ifAbsent: [ 'chunked' ]) = 'chunked'.
	contents := response entity contents.
	self assert: ((contents includesSubstring: 'Slashdot') or: [ contents includesSubstring: 'refresh' ])
! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testWritingBinary
	| response bytes string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	bytes := ByteArray streamContents: [ :stream | response writeOn: stream ].
	string := bytes asString.
	self assert: (string includesSubstring: '200 OK').
	self assert: (string includesSubstring: 'Okay')! !

!ZnResponseTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testWritingCharacter
	| response string |
	response := ZnResponse ok: (ZnEntity text: 'Okay').
	string := String streamContents: [ :stream | response writeOn: stream ].
	self assert: (string includesSubstring: '200 OK').
	self assert: (string includesSubstring: 'Okay')! !

TestCase subclass: #ZnServerTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnServerTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:36'!
port
	^ 1700 + 10 atRandom! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testAuthorizationFailed
	self withServerDo: [ :server | | response |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		response := ZnEasy get: (server localUrl addPathSegment: 'echo'; yourself).
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 401).
		self assert: ((response headers at: 'WWW-Authenticate') includesSubstring: 'Basic').
		self assert: ((response headers at: 'WWW-Authenticate') includesSubstring: 'Zinc') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testAuthorizationSuccessful
	self withServerDo: [ :server | | response |
		server authenticator: (ZnBasicAuthenticator username: 'foo' password: 'secret').
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself) username: 'foo' password: 'secret'.
		self assert: (response headers contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity string includesSubstring: 'Zinc').
		self assert: (response entity string includesSubstring: 'foo') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/12/2012 22:06'!
testDefault
	| port server |
	ZnServer stopDefault.
	self assert: ZnServer default isNil.
	port := self port.
	server := ZnServer startDefaultOn: port.
	self assert: ZnServer default notNil.
	self assert: ZnServer default == server.
	self assert: ZnServer default port = port.
	self assert: ZnServer default isRunning.
	self assert: (ZnServer managedServers includes: server).
	ZnServer stopDefault.
	self assert: ZnServer default isNil.
	self deny: server isRunning.
	self deny: (ZnServer managedServers includes: server).
	server := ZnServer startDefaultOn: port.
	"Starting the default again is actually a restart"
	ZnServer startDefaultOn: port.
	self assert: ZnServer default == server.
	ZnServer stopDefault! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/10/2012 17:42'!
testEcho
	self withServerDo: [ :server | | response |
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity contents includesSubstring: 'Zinc').
		self assert: (response entity contents includesSubstring: 'foo').
		self assert: (response entity contents includesSubstring: server printString) ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testEchoBinary
	self withServerDo: [ :server | | response entityIn entityOut |
		server reader: [ :stream | ZnRequest readBinaryFrom: stream ].
		entityIn := ZnEntity with: 'ABC' type: 'text/plain'.
		response := ZnEasy put: (server localUrl addPathSegment: 'echo'; yourself)  data: entityIn.
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		entityOut := ZnEntity with: entityIn string asByteArray type: entityIn contentType.
		self assert: (response entity contents includesSubstring: entityOut printString) ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testEchoLocalInterface
	| server response |
	(server := ZnServer on: self port)
		bindingAddress: NetNameResolver loopBackAddress.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		response := ZnEasy get: (server localUrl addPathSegments: #('echo' 'foo'); yourself).
		self assert: (response contentType = ZnMimeType textPlain).
		self assert: (response statusLine code = 200).
		self assert: (response entity contents includesSubstring: 'Zinc').
		self assert: (response entity contents includesSubstring: 'foo')
	]
		ensure: [ server stop ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/23/2012 18:20'!
testError
	self
		withServerDo: [ :server | 
			| url response |
			self deny: server debugMode.
			url := server localUrl
				addPathSegment: #error;
				queryAt: #message put: 'Test Error';
				yourself.
			response := ZnEasy get: url.
			self deny: response isSuccess.
			self assert: response code equals: 500.
			self assert: response contentType equals: ZnMimeType textPlain.
			self assert: (response entity contents includesSubstring: 'Test Error') ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testGetUnicodeUtf8
	self withServerDo: [ :server | | response html |
		response := ZnEasy get: (server localUrl addPathSegment: 'unicode'; yourself).
		self assert: (response contentType = ZnMimeType textHtml).
		self assert: (response statusLine code = 200).
		self assert: response contentType isCharSetUTF8.
		html := response entity contents.
		self assert: (html includesSubstring: 'Unicode').
		0 to: 16r024F do: [ :each | self assert: (html includes: each asCharacter) ] ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2013 13:36'!
testLocalUrl
	self
		withServerDo: [ :server | 
			self assert: server localUrl scheme equals: #http.
			self assert: server localUrl host equals: NetNameResolver loopBackName.
			self assert: server localUrl port equals: server port ]! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 11/10/2012 23:47'!
testSession
	self withServerDo: [ :server | | client sessionId |
		client := ZnClient new url: (server localUrl addPathSegment: #session); yourself.
		self assert: client session cookieJar cookies isEmpty.
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		sessionId := client session cookieJar cookies anyOne value.
		self assert: (client contents includesSubstring: sessionId).
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		self assert: client session cookieJar cookies anyOne value equals: sessionId.
		self assert: (client contents includesSubstring: sessionId) ]
! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/31/2012 16:44'!
testSessionExpired
	self withServerDo: [ :server | | client sessionId |
		client := ZnClient new url: (server localUrl addPathSegment: #session); yourself.
		self assert: client session cookieJar cookies isEmpty.
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		sessionId := client session cookieJar cookies anyOne value.
		self assert: (client contents includesSubstring: sessionId).
		"Kill the server session as if it was expired"
		server sessionManager removeSessionWithId: sessionId.
		"The client still presents the old session id but should get a new one"
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		self deny: client session cookieJar cookies anyOne value = sessionId ]
! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/31/2012 16:58'!
testSessionRoute
	self withServerDo: [ :server | | client sessionId |
		server route: 'r1'.
		self assert: server route equals: 'r1'.
		client := ZnClient new url: (server localUrl addPathSegment: #session); yourself.
		self assert: client session cookieJar cookies isEmpty.
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		sessionId := client session cookieJar cookies anyOne value.
		self assert: (client contents includesSubstring: sessionId).
		self assert: (sessionId endsWith: '.r1').
		client get.
		self assert: client isSuccess.
		self assert: client session cookieJar cookies size = 1.
		self assert: client session cookieJar cookies anyOne value equals: sessionId.
		self assert: (client contents includesSubstring: sessionId) ]
! !

!ZnServerTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/4/2013 13:39'!
testUrl
	self
		withServerDo: [ :server | 
			self assert: server url equals: server localUrl.
			server
				serverUrl:
					(ZnUrl new
						host: 'zn.stfx.eu';
						yourself).
			self assert: server url scheme equals: #http.
			self assert: server url host equals: 'zn.stfx.eu'.
			self assert: server url port equals: server port.
			server serverUrl: 'http://zn.stfx.eu:8080/zn'.
			self assert: server url scheme equals: #http.
			self assert: server url host equals: 'zn.stfx.eu'.
			self assert: server url port equals: 8080.
			self assert: server url path equals: 'zn' ]! !

!ZnServerTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 3/12/2012 20:36'!
withServerDo: block
	| server |
	server := ZnServer on: self port.
	[ 
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnStaticFileServerDelegateTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnStaticFileServerDelegateTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/14/2012 09:52'!
port
	^ 1700 + 10 atRandom! !

!ZnStaticFileServerDelegateTests methodsFor: 'running' stamp: 'SvenVanCaekenberghe 7/3/2012 00:35'!
setUp
	self tearDown.
	ZnFileSystemUtils
		newFileNamed: 'small.html' 
		do: [ :stream |
			stream nextPutAll: self smallHtml ]! !

!ZnStaticFileServerDelegateTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/14/2012 10:08'!
smallHtml
	^ '<html>
<head><title>Small</title></head>
<body><h1>Small</h1><p>This is a small HTML document</p></body>
</html>
'! !

!ZnStaticFileServerDelegateTests methodsFor: 'running' stamp: 'SvenVanCaekenberghe 7/3/2012 00:35'!
tearDown
	ZnFileSystemUtils deleteIfExists: 'small.html'
	! !

!ZnStaticFileServerDelegateTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 8/23/2012 14:34'!
testBasicGet
	self withServerDo: [ :server | | client |
		(client := ZnClient new) 
			beOneShot;
			url: server localUrl;
			addPath: #('local-files' 'small.html');
			get.
		self assert: client isSuccess.
		self assert: client response contentType = ZnMimeType textHtml.
		self assert: (client contents includesSubstring: 'Small').
		self 
			assert: (ZnUtils parseHttpDate: (client response headers at: 'Modification-Date'))
			equals: (ZnFileSystemUtils modificationTimeFor: 'small.html') asUTC asTimeStamp.
		self 
			assert: (ZnUtils parseHttpDate: (client response headers at: 'Expires')) > (DateAndTime now + 10 days).
		self 
			assert: (client response headers at: 'Cache-Control')
			equals: (server delegate maxAgeFor: ZnMimeType textHtml) ]! !

!ZnStaticFileServerDelegateTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 7/3/2012 00:40'!
testBasicHead
	self withServerDo: [ :server | | client |
		(client := ZnClient new) 
			beOneShot;
			url: server localUrl;
			addPath: #('local-files' 'small.html');
			head.
		self assert: client isSuccess.
		self assert: client response contentType = ZnMimeType textHtml.
		self deny: client response hasEntity.
		self 
			assert: (ZnUtils parseHttpDate: (client response headers at: 'Modification-Date'))
			equals: (ZnFileSystemUtils modificationTimeFor: 'small.html') asUTC asTimeStamp.
		self 
			assert: (ZnUtils parseHttpDate: (client response headers at: 'Expires')) > (DateAndTime now + 10 days).
		self 
			assert: (client response headers at: 'Cache-Control')
			equals: (server delegate maxAgeFor: ZnMimeType textHtml) ]! !

!ZnStaticFileServerDelegateTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 8/3/2012 22:47'!
testIfModifiedSinceNotModified
	self withServerDo: [ :server | | client |
		(client := ZnClient new) 
			beOneShot;
			url: server localUrl;
			addPath: #('local-files' 'small.html');
			"We have to cheat a little bit since our #setUp just created the file,
			it does not alter the semantics of what we try to test"
			setIfModifiedSince: (Date today addDays: 2);
			get.
		self assert: client response isNotModified.
		self deny: client response hasEntity ]! !

!ZnStaticFileServerDelegateTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 7/3/2012 00:38'!
withServerDo: block
	| server staticFileServerDelegate |
	server := ZnServer on: self port.
	[ 
		(staticFileServerDelegate := ZnStaticFileServerDelegate new)
			prefixFromString: 'local-files'; 
			directory: ZnFileSystemUtils defaultDirectory;
			mimeTypeExpirations: ZnStaticFileServerDelegate defaultMimeTypeExpirations. 
		server delegate: staticFileServerDelegate.
		server start.
		self assert: server isRunning & server isListening.
		block cull: server
	] 
		ensure: [ server stop ]! !

TestCase subclass: #ZnStatusLineTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnStatusLineTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/15/2010 14:09'!
testReading
	| statusLine string |
	string := 'HTTP/1.1 200 OK', String crlf.
	statusLine := ZnStatusLine readFrom: string readStream.
	self assert: statusLine code = 200.
	self assert: statusLine reason = 'OK'.
	self assert: statusLine version = ZnConstants defaultHTTPVersion ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:04'!
testReadingWrongCode
	| string |
	string := 'HTTP/1.0 1000 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpStatusCode ! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion
	| string |
	string := 'HTTP/0.9 200 OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'DamienPollet 8/4/2011 14:05'!
testReadingWrongVersion2
	| string |
	string := 'HTTP/0.9 Foo OK', String crlf.
	self should: [ ZnStatusLine readFrom: string readStream ] raise: ZnUnknownHttpVersion! !

!ZnStatusLineTests methodsFor: 'testing' stamp: 'NickAger 5/10/2011 09:03'!
testWriting
	| statusLine string |
	statusLine := ZnStatusLine ok.
	string := String streamContents: [ :stream | statusLine writeOn: stream ].
	self assert: string = ('HTTP/1.1 200 OK', String crlf)! !

TestCase subclass: #ZnUrlExtensionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUrlExtensionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/11/2012 10:20'!
testAsZnUrl
	| url1 url2 url3 |
	url1 := 'http://www.example.com:8080/foo/bar/doc.txt?x=1&y=2#mark'.
	self assert: url1 asZnUrl = url1 asUrl asZnUrl.
	url2 := 'http://www.google.com'.
	self assert: url2 asZnUrl = url2 asUrl asZnUrl.
	url3 := 'http://www.google.com?q=Pharo'.
	self assert: url3 asZnUrl = url3 asUrl asZnUrl.
	"self assert: '' asZnUrl = '' asUrl asZnUrl."
	"self assert: '/' asZnUrl = '/' asUrl asZnUrl."

! !

TestCase subclass: #ZnUserAgentSessionTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUserAgentSessionTests methodsFor: 'accessing' stamp: 'MattKennedy 9/28/2010 15:11'!
dummyCredential
	^ZnBasicCredential new 
		username: 'test'; 
		password: 'foobar';
		realm: 'dummy';
		domain: 'test.com';
		yourself! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/30/2011 22:00'!
testAccessors
	| session |
	session := ZnUserAgentSession new.
	self assert: (session cookieJar isKindOf: ZnCookieJar).
	self assert: (session credentials notNil)! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'MattKennedy 9/28/2010 15:14'!
testAddCredential
	| session count |
	session := ZnUserAgentSession new.
	count := session credentials size.
	session addCredential: self dummyCredential.
	self assert: ((session credentials size) = (count + 1))! !

!ZnUserAgentSessionTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 12/7/2010 00:00'!
testWithCookieJar
	self assert: ((ZnUserAgentSession withCookieJar: ZnCookieJar new) notNil)! !

TestCase subclass: #ZnUtilsTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zinc-Tests'!

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 3/21/2011 20:25'!
testBase64
	| short long encoded legalCharactes |
	legalCharactes := (String withAll: ($A to: $Z), ($a to: $z), ($0 to: $9)), '='.
	short := String withAll: ((1 to: 16) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: short.
	self assert: (ZnUtils decodeBase64: encoded) = short.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ]).
	"We don't want line breaks!!"
	long := String withAll: ((1 to: 64) collect: [ :each | 'abc' atRandom ]).
	encoded := ZnUtils encodeBase64: long.
	self assert: (ZnUtils decodeBase64: encoded) = long.
	self assert: (encoded allSatisfy: [ :each | legalCharactes includes: each ])
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:09'!
testCapitalizeString
	self assert: (ZnUtils capitalizeString: 'content-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'CONTENT-type') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'content-TYPE') = 'Content-Type'.
	self assert: (ZnUtils capitalizeString: 'WWW-Authenticate') = 'Www-Authenticate'.
	self assert: (ZnUtils capitalizeString: 'Content-MD5') = 'Content-Md5'.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'PaulDeBruicker 04/10/2011 10:48'!
testHttpDate
	| timestamp string |
	timestamp := (DateAndTime year: 2010 month: 9 day: 1 hour: 10 minute: 10 second: 10 offset: 0 seconds).
	string := ZnUtils httpDate: timestamp.
	self assert: (string = 'Wed, 01 Sep 2010 10:10:10 GMT')
	! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 9/10/2010 20:10'!
testIsCapitalizedString
	self assert: (ZnUtils isCapitalizedString: 'Content-Type').
	self assert: (ZnUtils isCapitalizedString: 'CONTENT-type') not.
	self assert: (ZnUtils isCapitalizedString: 'content-TYPE') not.
	self assert: (ZnUtils isCapitalizedString: 'WWW-Authenticate') not.
	self assert: (ZnUtils isCapitalizedString: 'Connection')! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SeanDeNigris 5/10/2012 11:58'!
testParseHttpDate
	"RFC 822, updated by RFC 1123"
	
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue, 13 Sep 2011 08:04:49 GMT'.
	self assert: timeStamp dayOfMonth = 13.
	self assert: timeStamp monthIndex = 9.
	self assert: timeStamp year = 2011.
	self assert: timeStamp hour = 8.
	self assert: timeStamp minute = 4.
	self assert: timeStamp second = 49.
	self assert: timeStamp offset = Duration zero.! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SeanDeNigris 5/10/2012 11:58'!
testParseHttpDateAlternative1
	"ANSI C's asctime() format"
	
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue Jan 01 00:00:01 2036'.
	self assert: timeStamp dayOfMonth = 1.
	self assert: timeStamp monthIndex = 1.
	self assert: timeStamp year = 2036.
	self assert: timeStamp hour = 0.
	self assert: timeStamp minute = 0.
	self assert: timeStamp second = 1.
	self assert: timeStamp offset = Duration zero! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SeanDeNigris 5/10/2012 11:58'!
testParseHttpDateDashes
	"RFC 850, obsoleted by RFC 1036"
	
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tuesday, 13-Sep-11 08:04:49 GMT'.
	self assert: timeStamp dayOfMonth = 13.
	self assert: timeStamp monthIndex = 9.
	self assert: timeStamp year = 2011.
	self assert: timeStamp hour = 8.
	self assert: timeStamp minute = 4.
	self assert: timeStamp second = 49.
	self assert: timeStamp offset = Duration zero! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/10/2012 20:27'!
testParseHttpDateDashesAlternative1
	"RFC 850, obsoleted by RFC 1036"
	
	| timeStamp |
	timeStamp := ZnUtils parseHttpDate: 'Tue, 13-Sep-2011 08:04:49 GMT'.
	self assert: timeStamp dayOfMonth = 13.
	self assert: timeStamp monthIndex = 9.
	self assert: timeStamp year = 2011.
	self assert: timeStamp hour = 8.
	self assert: timeStamp minute = 4.
	self assert: timeStamp second = 49.
	self assert: timeStamp offset = Duration zero! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:57'!
testReadUpToEndBinary
	| data |
	data := ByteArray streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: #(1 2 3) atRandom ] ].
	self assert: (ZnUtils readUpToEnd: data readStream limit: nil) = data.
	self assert: (ZnUtils readUpToEnd: data readStream limit: 10000) = data.
	self should: [ ZnUtils readUpToEnd: data readStream limit: 9999 ] raise: ZnEntityTooLarge 
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:58'!
testReadUpToEndNonBinary
	| data |
	data := String streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: 'abc' atRandom ] ].
	self assert: (ZnUtils readUpToEnd: data readStream limit: nil) = data.
	self assert: (ZnUtils readUpToEnd: data readStream limit: 10000) = data.
	self should: [ ZnUtils readUpToEnd: data readStream limit: 9999 ] raise: ZnEntityTooLarge 
! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:56'!
testStreamingBinary
	| data in out |
	data := ByteArray streamContents: [ :stream | 
		1 to: 10000 do: [ :each |
			stream nextPut: #(1 2 3) atRandom ] ].
	in := data readStream.
	out := WriteStream on: (ByteArray new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/3/2012 22:36'!
testStreamingBinaryWithoutSize
	| data in out |
	data := ByteArray streamContents: [ :stream | 
		1 to: 10000 do: [ :each |
			stream nextPut: #(1 2 3) atRandom ] ].
	in := data readStream.
	out := WriteStream on: (ByteArray new: data size).
	ZnUtils streamFrom: in to: out.
	self assert: in atEnd.
	self assert: out contents equals: data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 1/31/2012 12:56'!
testStreamingNonBinary
	| data in out |
	data := String streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: 'abc' atRandom ] ].
	in := data readStream.
	out := WriteStream on: (String new: data size).
	ZnUtils streamFrom: in to: out size: data size.
	self assert: in atEnd.
	self assert: out contents = data ! !

!ZnUtilsTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 8/3/2012 22:37'!
testStreamingNonBinaryWithoutSize
	| data in out |
	data := String streamContents: [ :stream | 
		1 to: 10000 do: [ :each | 
			stream nextPut: 'abc' atRandom ] ].
	in := data readStream.
	out := WriteStream on: (String new: data size).
	ZnUtils streamFrom: in to: out.
	self assert: in atEnd.
	self assert: out contents equals: data ! !
